Class: RubySketch::Sprite
- Inherits:
-
Object
- Object
- RubySketch::Sprite
- Includes:
- Xot::Inspectable
- Defined in:
- lib/rubysketch/sprite.rb
Overview
Sprite object.
Instance Method Summary collapse
-
#angle ⇒ Numeric
Returns the rotation angle of the sprite.
-
#angle=(angle) ⇒ Numeric
Sets the rotation angle of the sprite.
-
#angleFixed? ⇒ Boolean
Returns the angle of the sprite is fixed or not.
-
#bottom ⇒ Numeric
Returns the bottom position of the sprite.
-
#bottom=(bottom) ⇒ Numeric
Set the bottom position of the sprite.
-
#center ⇒ Vector
Returns the center position of the sprite.
-
#center=(arg) ⇒ Vector
Sets the center position of the sprite.
-
#clickCount ⇒ Numeric
Returns the mouse button click count on the sprite.
-
#contact(&block) ⇒ nil
Defines contact block.
-
#contact?(&block) ⇒ nil
Defines contact? block.
-
#contact_end(&block) ⇒ nil
Defines contact_end block.
-
#density ⇒ Numeric
(also: #dens)
Returns the density of the sprite.
-
#density=(n) ⇒ Numeric
(also: #dens=)
Sets the density of the sprite.
-
#draw(&block) ⇒ nil
Defines draw block.
-
#dynamic=(bool) ⇒ Boolean
Sets whether the sprite is movable by the physics engine.
-
#dynamic? ⇒ Boolean
Returns whether the sprite is movable by the physics engine.
-
#fixAngle(fix = true) ⇒ Sprite
Fixes the angle of the sprite.
-
#friction ⇒ Numeric
(also: #fric)
Returns the friction of the sprite.
-
#friction=(n) ⇒ Numeric
(also: #fric=)
Sets the friction of the sprite.
-
#fromScreen(vec) ⇒ Vector
Converts a vector from the screen coordinate.
-
#height ⇒ Numeric
(also: #h)
Returns the height of the sprite.
-
#height=(h) ⇒ Numeric
(also: #h=)
Sets the height of the sprite.
-
#hidden? ⇒ Boolean
Returns the sprite is visible.
-
#hide ⇒ Sprite
Hides the sprite.
-
#image ⇒ Image
Returns the image of the sprite.
-
#image=(img) ⇒ Image
Sets the sprite image.
-
#initialize(x = 0, y = 0, w = nil, h = nil, image: nil, offset: nil, shape: nil, physics: true, context: nil) ⇒ Sprite
constructor
Initialize sprite object.
-
#left ⇒ Numeric
Returns the left position of the sprite.
-
#left=(n) ⇒ Numeric
Set the left position of the sprite.
-
#mouseButton ⇒ LEFT, ...
Returns the mouse button clicked on the sprite.
-
#mouseClicked(&block) ⇒ nil
Defines mouseClicked block.
-
#mouseDragged(&block) ⇒ nil
Defines mouseDragged block.
-
#mouseMoved(&block) ⇒ nil
Defines mouseMoved block.
-
#mousePressed(&block) ⇒ Boolean
Defines mousePressed block.
-
#mouseReleased(&block) ⇒ nil
Defines mouseReleased block.
-
#mouseX ⇒ Numeric
Returns the x-position of the mouse in the sprite coordinates.
-
#mouseY ⇒ Numeric
Returns the y-position of the mouse in the sprite coordinates.
-
#offset ⇒ Vector
Returns the offset of the sprite image.
-
#offset=(arg) ⇒ Vector
Sets the offset of the sprite image.
-
#ox ⇒ Numeric
Returns the x-axis offset of the sprite image.
-
#ox=(n) ⇒ Numeric
Sets the x-axis offset of the sprite image.
-
#oy ⇒ Numeric
Returns the y-axis offset of the sprite image.
-
#oy=(n) ⇒ Numeric
Sets the y-axis offset of the sprite image.
-
#pivot ⇒ Array<Numeric>
Returns the rotation center of the sprite.
-
#pivot=(array) ⇒ Array<Numeric>
Sets the rotation center of the sprite.
-
#pmouseX ⇒ Numeric
Returns the previous x-position of the mouse in the sprite coordinates.
-
#pmouseY ⇒ Numeric
Returns the previous y-position of the mouse in the sprite coordinates.
-
#position ⇒ Vector
(also: #pos)
Returns the position of the sprite.
-
#position=(arg) ⇒ Vector
(also: #pos=)
Sets the position of the sprite.
-
#restitution ⇒ Numeric
(also: #rest)
Returns the restitution of the sprite.
-
#restitution=(n) ⇒ Numeric
(also: #rest=)
Sets the restitution of the sprite.
-
#right ⇒ Numeric
Returns the right position of the sprite.
-
#right=(n) ⇒ Numeric
Set the right position of the sprite.
-
#sensor=(state) ⇒ Boolean
Set this sprite as a sensor object.
-
#sensor? ⇒ Boolean
Returns weather the shape is a sensor or not.
-
#show ⇒ Sprite
Shows the sprite.
-
#size ⇒ Vector
Returns the size of the sprite.
-
#size=(arg) ⇒ Vector
Returns the size of the sprite.
-
#top ⇒ Numeric
Returns the top position of the sprite.
-
#top=(n) ⇒ Numeric
Set the top position of the sprite.
-
#toScreen(vec) ⇒ Vector
Converts a vector to the screen coordinate.
-
#touchEnded(&block) ⇒ nil
Defines touchEnded block.
-
#touches ⇒ Array<Touch>
Returns the touch objects touched on the sprite.
-
#touchMoved(&block) ⇒ nil
Defines touchMoved block.
-
#touchStarted(&block) ⇒ nil
Defines touchStarted block.
-
#update(&block) ⇒ nil
Defines update block.
-
#velocity ⇒ Vector
(also: #vel)
Returns the velocity of the sprite.
-
#velocity=(arg) ⇒ Vector
(also: #vel=)
Sets the velocity of the sprite.
-
#vx ⇒ Numeric
Returns the x-axis velocity of the sprite.
-
#vx=(n) ⇒ Numeric
Sets the x-axis velocity of the sprite.
-
#vy ⇒ Numeric
Returns the y-axis velocity of the sprite.
-
#vy=(n) ⇒ Numeric
Sets the y-axis velocity of the sprite.
-
#width ⇒ Numeric
(also: #w)
Returns the width of the sprite.
-
#width=(w) ⇒ Numeric
(also: #w=)
Sets the width of the sprite.
-
#x ⇒ Numeric
Returns the x-coordinate position of the sprite.
-
#x=(n) ⇒ Numeric
Set the x-coordinate position of the sprite.
-
#y ⇒ Numeric
Returns the y-coordinate position of the sprite.
-
#y=(n) ⇒ Numeric
Set the y-coordinate position of the sprite.
-
#z ⇒ Numeric
Returns the z-coordinate position of the sprite.
-
#z=(n) ⇒ Numeric
Set the z-coordinate position of the sprite.
Constructor Details
#new(x, y, w, h) ⇒ Sprite #new(image: img) ⇒ Sprite #new(x, y, image: img) ⇒ Sprite #new(x, y, image: img, offset: off) ⇒ Sprite #new(x, y, image: img, shape: shp) ⇒ Sprite #new(x, y, image: img, offset: off, shape: shp) ⇒ Sprite #new(x, y, shape: shp) ⇒ Sprite
Initialize sprite object.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/rubysketch/sprite.rb', line 56 def initialize( x = 0, y = 0, w = nil, h = nil, image: nil, offset: nil, shape: nil, physics: true, context: nil) w ||= (image&.width || shape&.width || 0) h ||= (image&.height || shape&.height || 0) raise 'invalid size' unless w >= 0 && h >= 0 raise 'invalid image' if image && !image.getInternal__.is_a?(Rays::Image) raise 'invalid shape' if shape && !shape.getInternal__.is_a?(Reflex::Shape) @context__ = context || Context.context__ @shape__ = shape @view__ = View.new( self, x: x, y: y, w: w, h: h, shape: @shape__, physics: physics, back: :white) @view__.set density: 1, friction: 0, restitution: 0 self.image = image if image self.offset = offset if offset end |
Instance Method Details
#angle ⇒ Numeric
Returns the rotation angle of the sprite.
349 350 351 352 |
# File 'lib/rubysketch/sprite.rb', line 349 def angle() a, c = @view__.angle, @context__ c ? c.fromDegrees__(a) : a * Processing::GraphicsContext::DEG2RAD__ end |
#angle=(angle) ⇒ Numeric
Sets the rotation angle of the sprite.
360 361 362 363 364 365 |
# File 'lib/rubysketch/sprite.rb', line 360 def angle=(angle) c = @context__ @view__.angle = c ? c.toDegrees__(angle) : angle * Processing::GraphicsContext::RAD2DEG__ angle end |
#angleFixed? ⇒ Boolean
Returns the angle of the sprite is fixed or not.
382 383 384 |
# File 'lib/rubysketch/sprite.rb', line 382 def angleFixed?() @view__.fix_angle? end |
#bottom ⇒ Numeric
Returns the bottom position of the sprite.
249 250 251 |
# File 'lib/rubysketch/sprite.rb', line 249 def bottom() @view__.bottom end |
#bottom=(bottom) ⇒ Numeric
Set the bottom position of the sprite.
259 260 261 |
# File 'lib/rubysketch/sprite.rb', line 259 def bottom=(bottom) @view__.bottom = bottom end |
#center ⇒ Vector
Returns the center position of the sprite.
267 268 269 |
# File 'lib/rubysketch/sprite.rb', line 267 def center() Vector.new(x + w / 2, y + h / 2, z) end |
#center=(vec) ⇒ Vector #center=(ary) ⇒ Vector
Sets the center position of the sprite.
281 282 283 284 285 |
# File 'lib/rubysketch/sprite.rb', line 281 def center=(arg) x, y = *(arg.is_a?(Vector) ? arg.getInternal__.to_a : arg) self.pos = [x - w / 2, y - h / 2, z] self.center end |
#clickCount ⇒ Numeric
Returns the mouse button click count on the sprite.
718 719 720 |
# File 'lib/rubysketch/sprite.rb', line 718 def clickCount() @view__.clickCount end |
#contact(&block) ⇒ nil
Defines contact block.
881 882 883 884 |
# File 'lib/rubysketch/sprite.rb', line 881 def contact(&block) @view__.contact = block if block nil end |
#contact?(&block) ⇒ nil
Defines contact? block.
909 910 911 912 |
# File 'lib/rubysketch/sprite.rb', line 909 def contact?(&block) @view__.will_contact = block if block nil end |
#contact_end(&block) ⇒ nil
Defines contact_end block.
895 896 897 898 |
# File 'lib/rubysketch/sprite.rb', line 895 def contact_end(&block) @view__.contact_end = block if block nil end |
#density ⇒ Numeric Also known as: dens
Returns the density of the sprite.
577 578 579 |
# File 'lib/rubysketch/sprite.rb', line 577 def density() @view__.density end |
#density=(n) ⇒ Numeric Also known as: dens=
Sets the density of the sprite.
587 588 589 590 |
# File 'lib/rubysketch/sprite.rb', line 587 def density=(n) @view__.density = n n end |
#draw(&block) ⇒ nil
Defines draw block.
755 756 757 758 |
# File 'lib/rubysketch/sprite.rb', line 755 def draw(&block) @drawBlock__ = block if block nil end |
#dynamic=(bool) ⇒ Boolean
Sets whether the sprite is movable by the physics engine.
568 569 570 571 |
# File 'lib/rubysketch/sprite.rb', line 568 def dynamic=(bool) @view__.dynamic = bool bool end |
#dynamic? ⇒ Boolean
Returns whether the sprite is movable by the physics engine.
558 559 560 |
# File 'lib/rubysketch/sprite.rb', line 558 def dynamic?() @view__.dynamic? end |
#fixAngle(fix = true) ⇒ Sprite
Fixes the angle of the sprite.
373 374 375 376 |
# File 'lib/rubysketch/sprite.rb', line 373 def fixAngle(fix = true) @view__.fix_angle = fix self end |
#friction ⇒ Numeric Also known as: fric
Returns the friction of the sprite.
596 597 598 |
# File 'lib/rubysketch/sprite.rb', line 596 def friction() @view__.friction end |
#friction=(n) ⇒ Numeric Also known as: fric=
Sets the friction of the sprite.
606 607 608 609 |
# File 'lib/rubysketch/sprite.rb', line 606 def friction=(n) @view__.friction = n n end |
#fromScreen(vec) ⇒ Vector
Converts a vector from the screen coordinate
660 661 662 |
# File 'lib/rubysketch/sprite.rb', line 660 def fromScreen(vec) @view__.from_parent(vec.getInternal__).toVector end |
#height ⇒ Numeric Also known as: h
Returns the height of the sprite.
326 327 328 |
# File 'lib/rubysketch/sprite.rb', line 326 def height() @view__.height end |
#height=(h) ⇒ Numeric Also known as: h=
Sets the height of the sprite.
336 337 338 |
# File 'lib/rubysketch/sprite.rb', line 336 def height=(h) @view__.height = h end |
#hidden? ⇒ Boolean
Returns the sprite is visible
103 104 105 |
# File 'lib/rubysketch/sprite.rb', line 103 def hidden?() @view__.hidden? end |
#hide ⇒ Sprite
Hides the sprite
Since one call to “hide()” increases the hide count, it is necessary to call “show()” n times to make the sprite visible again after calling “hide()” n times.
94 95 96 97 |
# File 'lib/rubysketch/sprite.rb', line 94 def hide() @view__.hide self end |
#image ⇒ Image
Returns the image of the sprite.
474 475 476 |
# File 'lib/rubysketch/sprite.rb', line 474 def image() @image__ end |
#image=(img) ⇒ Image
Sets the sprite image.
484 485 486 |
# File 'lib/rubysketch/sprite.rb', line 484 def image=(img) @image__ = img end |
#left ⇒ Numeric
Returns the left position of the sprite.
194 195 196 |
# File 'lib/rubysketch/sprite.rb', line 194 def left() @view__.left end |
#left=(n) ⇒ Numeric
Set the left position of the sprite.
204 205 206 207 |
# File 'lib/rubysketch/sprite.rb', line 204 def left=(n) @view__.left = n n end |
#mouseButton ⇒ LEFT, ...
Returns the mouse button clicked on the sprite.
710 711 712 |
# File 'lib/rubysketch/sprite.rb', line 710 def mouseButton() @view__.mouseButton end |
#mouseClicked(&block) ⇒ nil
Defines mouseClicked block.
825 826 827 828 |
# File 'lib/rubysketch/sprite.rb', line 825 def mouseClicked(&block) @view__.mouseClicked = block if block nil end |
#mouseDragged(&block) ⇒ nil
Defines mouseDragged block.
811 812 813 814 |
# File 'lib/rubysketch/sprite.rb', line 811 def mouseDragged(&block) @view__.mouseDragged = block if block nil end |
#mouseMoved(&block) ⇒ nil
Defines mouseMoved block.
797 798 799 800 |
# File 'lib/rubysketch/sprite.rb', line 797 def mouseMoved(&block) @view__.mouseMoved = block if block nil end |
#mousePressed(&block) ⇒ Boolean
Defines mousePressed block.
769 770 771 772 |
# File 'lib/rubysketch/sprite.rb', line 769 def mousePressed(&block) @view__.mousePressed = block if block @view__.mousePressed? end |
#mouseReleased(&block) ⇒ nil
Defines mouseReleased block.
783 784 785 786 |
# File 'lib/rubysketch/sprite.rb', line 783 def mouseReleased(&block) @view__.mouseReleased = block if block nil end |
#mouseX ⇒ Numeric
Returns the x-position of the mouse in the sprite coordinates.
678 679 680 |
# File 'lib/rubysketch/sprite.rb', line 678 def mouseX() @view__.mouseX end |
#mouseY ⇒ Numeric
Returns the y-position of the mouse in the sprite coordinates.
686 687 688 |
# File 'lib/rubysketch/sprite.rb', line 686 def mouseY() @view__.mouseY end |
#offset ⇒ Vector
Returns the offset of the sprite image.
492 493 494 |
# File 'lib/rubysketch/sprite.rb', line 492 def offset() @offset__ end |
#offset=(vec) ⇒ Vector #velocity=(ary) ⇒ Vector
Sets the offset of the sprite image.
506 507 508 509 510 511 512 513 514 515 |
# File 'lib/rubysketch/sprite.rb', line 506 def offset=(arg) @offset__ = case arg when Vector then arg when Array then Vector.new(arg[0] || 0, arg[1] || 0) when nil then nil else raise ArgumentError end @offset__ end |
#ox ⇒ Numeric
Returns the x-axis offset of the sprite image.
521 522 523 |
# File 'lib/rubysketch/sprite.rb', line 521 def ox() @offset__&.x || 0 end |
#ox=(n) ⇒ Numeric
Sets the x-axis offset of the sprite image.
531 532 533 534 |
# File 'lib/rubysketch/sprite.rb', line 531 def ox=(n) self.offset = [n, oy] n end |
#oy ⇒ Numeric
Returns the y-axis offset of the sprite image.
540 541 542 |
# File 'lib/rubysketch/sprite.rb', line 540 def oy() @offset__&.y || 0 end |
#oy=(n) ⇒ Numeric
Sets the y-axis offset of the sprite image.
550 551 552 |
# File 'lib/rubysketch/sprite.rb', line 550 def oy=(n) self.offset = [ox, n] end |
#pivot ⇒ Array<Numeric>
Returns the rotation center of the sprite.
390 391 392 |
# File 'lib/rubysketch/sprite.rb', line 390 def pivot() @view__.pivot.to_a[0, 2] end |
#pivot=(array) ⇒ Array<Numeric>
Sets the rotation center of the sprite.
- 0.0, 0.0
-
is the left-top, [1.0, 1.0] is the right-bottom, and [0.5, 0.5] is the center.
401 402 403 404 |
# File 'lib/rubysketch/sprite.rb', line 401 def pivot=(array) @view__.pivot = array pivot end |
#pmouseX ⇒ Numeric
Returns the previous x-position of the mouse in the sprite coordinates.
694 695 696 |
# File 'lib/rubysketch/sprite.rb', line 694 def pmouseX() @view__.pmouseX end |
#pmouseY ⇒ Numeric
Returns the previous y-position of the mouse in the sprite coordinates.
702 703 704 |
# File 'lib/rubysketch/sprite.rb', line 702 def pmouseY() @view__.pmouseY end |
#position ⇒ Vector Also known as: pos
Returns the position of the sprite.
111 112 113 |
# File 'lib/rubysketch/sprite.rb', line 111 def position() @view__.position.toVector end |
#position=(vec) ⇒ Vector #position=(ary) ⇒ Vector Also known as: pos=
Sets the position of the sprite.
125 126 127 128 |
# File 'lib/rubysketch/sprite.rb', line 125 def position=(arg) @view__.position = arg.is_a?(Vector) ? arg.getInternal__ : arg arg end |
#restitution ⇒ Numeric Also known as: rest
Returns the restitution of the sprite.
615 616 617 |
# File 'lib/rubysketch/sprite.rb', line 615 def restitution() @view__.restitution end |
#restitution=(n) ⇒ Numeric Also known as: rest=
Sets the restitution of the sprite.
625 626 627 628 |
# File 'lib/rubysketch/sprite.rb', line 625 def restitution=(n) @view__.restitution = n n end |
#right ⇒ Numeric
Returns the right position of the sprite.
231 232 233 |
# File 'lib/rubysketch/sprite.rb', line 231 def right() @view__.right end |
#right=(n) ⇒ Numeric
Set the right position of the sprite.
241 242 243 |
# File 'lib/rubysketch/sprite.rb', line 241 def right=(n) @view__.right = n end |
#sensor=(state) ⇒ Boolean
Set this sprite as a sensor object. Sensor object receives contact events, but no collisions.
642 643 644 |
# File 'lib/rubysketch/sprite.rb', line 642 def sensor=(state) @view__.sensor = state end |
#sensor? ⇒ Boolean
Returns weather the shape is a sensor or not.
650 651 652 |
# File 'lib/rubysketch/sprite.rb', line 650 def sensor?() @view__.sensor? end |
#show ⇒ Sprite
Shows the sprite
Since one call to “hide()” increases the hide count, it is necessary to call “show()” n times to make the sprite visible again after calling “hide()” n times.
83 84 85 86 |
# File 'lib/rubysketch/sprite.rb', line 83 def show() @view__.show self end |
#size ⇒ Vector
Returns the size of the sprite.
291 292 293 |
# File 'lib/rubysketch/sprite.rb', line 291 def size() @view__.size.toVector end |
#size=(arg) ⇒ Vector
Returns the size of the sprite.
299 300 301 302 |
# File 'lib/rubysketch/sprite.rb', line 299 def size=(arg) @view__.size = arg.is_a?(Vector) ? arg.getInternal__ : arg arg end |
#top ⇒ Numeric
Returns the top position of the sprite.
213 214 215 |
# File 'lib/rubysketch/sprite.rb', line 213 def top() @view__.top end |
#top=(n) ⇒ Numeric
Set the top position of the sprite.
223 224 225 |
# File 'lib/rubysketch/sprite.rb', line 223 def top=(n) @view__.top = n end |
#toScreen(vec) ⇒ Vector
Converts a vector to the screen coordinate
670 671 672 |
# File 'lib/rubysketch/sprite.rb', line 670 def toScreen(vec) @view__.to_parent(vec.getInternal__).toVector end |
#touchEnded(&block) ⇒ nil
Defines touchEnded block.
853 854 855 856 |
# File 'lib/rubysketch/sprite.rb', line 853 def touchEnded(&block) @view__.touchEnded = block if block nil end |
#touches ⇒ Array<Touch>
Returns the touch objects touched on the sprite.
726 727 728 |
# File 'lib/rubysketch/sprite.rb', line 726 def touches() @view__.touches end |
#touchMoved(&block) ⇒ nil
Defines touchMoved block.
867 868 869 870 |
# File 'lib/rubysketch/sprite.rb', line 867 def touchMoved(&block) @view__.touchMoved = block if block nil end |
#touchStarted(&block) ⇒ nil
Defines touchStarted block.
839 840 841 842 |
# File 'lib/rubysketch/sprite.rb', line 839 def touchStarted(&block) @view__.touchStarted = block if block nil end |
#update(&block) ⇒ nil
Defines update block.
739 740 741 742 |
# File 'lib/rubysketch/sprite.rb', line 739 def update(&block) @view__.update = block if block nil end |
#velocity ⇒ Vector Also known as: vel
Returns the velocity of the sprite.
410 411 412 |
# File 'lib/rubysketch/sprite.rb', line 410 def velocity() @view__.velocity.toVector end |
#velocity=(vec) ⇒ Vector #velocity=(ary) ⇒ Vector Also known as: vel=
Sets the velocity of the sprite.
424 425 426 427 |
# File 'lib/rubysketch/sprite.rb', line 424 def velocity=(arg) @view__.velocity = arg.is_a?(Vector) ? arg.getInternal__ : arg arg end |
#vx ⇒ Numeric
Returns the x-axis velocity of the sprite.
433 434 435 |
# File 'lib/rubysketch/sprite.rb', line 433 def vx() @view__.velocity.x end |
#vx=(n) ⇒ Numeric
Sets the x-axis velocity of the sprite.
443 444 445 446 |
# File 'lib/rubysketch/sprite.rb', line 443 def vx=(n) @view__.velocity = @view__.velocity.tap {|v| v.x = n} n end |
#vy ⇒ Numeric
Returns the y-axis velocity of the sprite.
452 453 454 |
# File 'lib/rubysketch/sprite.rb', line 452 def vy() @view__.velocity.y end |
#vy=(n) ⇒ Numeric
Sets the y-axis velocity of the sprite.
462 463 464 465 |
# File 'lib/rubysketch/sprite.rb', line 462 def vy=(n) @view__.velocity = @view__.velocity.tap {|v| v.y = n} n end |
#width ⇒ Numeric Also known as: w
Returns the width of the sprite.
308 309 310 |
# File 'lib/rubysketch/sprite.rb', line 308 def width() @view__.width end |
#width=(w) ⇒ Numeric Also known as: w=
Sets the width of the sprite.
318 319 320 |
# File 'lib/rubysketch/sprite.rb', line 318 def width=(w) @view__.width = w end |
#x ⇒ Numeric
Returns the x-coordinate position of the sprite.
134 135 136 |
# File 'lib/rubysketch/sprite.rb', line 134 def x() @view__.x end |
#x=(n) ⇒ Numeric
Set the x-coordinate position of the sprite.
144 145 146 147 |
# File 'lib/rubysketch/sprite.rb', line 144 def x=(n) @view__.x = n n end |
#y ⇒ Numeric
Returns the y-coordinate position of the sprite.
153 154 155 |
# File 'lib/rubysketch/sprite.rb', line 153 def y() @view__.y end |
#y=(n) ⇒ Numeric
Set the y-coordinate position of the sprite.
163 164 165 166 |
# File 'lib/rubysketch/sprite.rb', line 163 def y=(n) @view__.y = n n end |
#z ⇒ Numeric
Returns the z-coordinate position of the sprite.
172 173 174 |
# File 'lib/rubysketch/sprite.rb', line 172 def z() @view__.z end |
#z=(n) ⇒ Numeric
Set the z-coordinate position of the sprite.
182 183 184 185 |
# File 'lib/rubysketch/sprite.rb', line 182 def z=(n) @view__.z = n n end |